aboutsummaryrefslogtreecommitdiff
path: root/lib/VMCore/Module.cpp
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2001-12-03 22:26:30 +0000
committerChris Lattner <sabre@nondot.org>2001-12-03 22:26:30 +0000
commite9bb2df410f7a22decad9a883f7139d5857c1520 (patch)
treef6ca07fb5f5de1df8a2572142a707f56bf25c6e6 /lib/VMCore/Module.cpp
parent9ef18310beaabe7abfa712a3c761036ea2d17caa (diff)
Rename ConstPoolVal -> Constant
Rename ConstPool* -> Constant* Rename ConstPoolVals.h -> ConstantVals.h git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@1407 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/VMCore/Module.cpp')
-rw-r--r--lib/VMCore/Module.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/VMCore/Module.cpp b/lib/VMCore/Module.cpp
index 86b944d79f..a42535580b 100644
--- a/lib/VMCore/Module.cpp
+++ b/lib/VMCore/Module.cpp
@@ -11,7 +11,7 @@
#include "llvm/InstrTypes.h"
#include "llvm/ValueHolderImpl.h"
#include "llvm/Type.h"
-#include "llvm/ConstPoolVals.h"
+#include "llvm/ConstantVals.h"
#include "Support/STLExtras.h"
#include <map>
@@ -24,7 +24,7 @@ template class ValueHolder<Method, Module, Module>;
// Define the GlobalValueRefMap as a struct that wraps a map so that we don't
// have Module.h depend on <map>
//
-struct GlobalValueRefMap : public map<GlobalValue*, ConstPoolPointerRef*>{
+struct GlobalValueRefMap : public map<GlobalValue*, ConstantPointerRef*>{
};
@@ -63,7 +63,7 @@ void Module::dropAllReferences() {
if (GVRefMap) {
for (GlobalValueRefMap::iterator I = GVRefMap->begin(), E = GVRefMap->end();
I != E; ++I) {
// Delete the ConstPoolPointerRef node...
I->second->destroyConstant();
}
@@ -89,24 +89,24 @@ bool Module::reduceApply(bool (*Func)(const Method*)) const {
}
// Accessor for the underlying GlobalValRefMap...
-ConstPoolPointerRef *Module::getConstPoolPointerRef(GlobalValue *V){
+ConstantPointerRef *Module::getConstantPointerRef(GlobalValue *V){
// Create ref map lazily on demand...
if (GVRefMap == 0) GVRefMap = new GlobalValueRefMap();
GlobalValueRefMap::iterator I = GVRefMap->find(V);
if (I != GVRefMap->end()) return I->second;
- ConstPoolPointerRef *Ref = new ConstPoolPointerRef(V);
+ ConstantPointerRef *Ref = new ConstantPointerRef(V);
GVRefMap->insert(make_pair(V, Ref));
return Ref;
}
-void Module::mutateConstPoolPointerRef(GlobalValue *OldGV, GlobalValue *NewGV) {
+void Module::mutateConstantPointerRef(GlobalValue *OldGV, GlobalValue *NewGV) {
GlobalValueRefMap::iterator I = GVRefMap->find(OldGV);
assert(I != GVRefMap->end() &&
- "mutateConstPoolPointerRef; OldGV not in table!");
- ConstPoolPointerRef *Ref = I->second;
+ "mutateConstantPointerRef; OldGV not in table!");
+ ConstantPointerRef *Ref = I->second;
// Remove the old entry...
GVRefMap->erase(I);
@@ -63,7 +63,7 @@ void Module::dropAllReferences() {
for (GlobalValueRefMap::iterator I = GVRefMap->begin(), E = GVRefMap->end();
I != E; ++I) {
- // Delete the ConstPoolPointerRef node...
+ // Delete the ConstantPointerRef node...
I->second->destroyConstant();
}